From linux-kernel-owner+greg=40kroah.com-S1750801AbVHKViT@vger.kernel.org Thu Aug 11 14:42:00 2005
Date: Thu, 11 Aug 2005 23:38:52 +0200
From: Jean Delvare <khali@linux-fr.org>
Subject: I2C: Kill i2c_algorithm.id (3/7)
Message-Id: <20050811233852.6f11b2f9.khali@linux-fr.org>

Don't rely on i2c_algorithm.id to alter the i2c adapter's id, use the
I2C_ALGO_* value directly instead, because i2c_algorithm will soon
have no id member no more.

Signed-off-by: Jean Delvare <khali@linux-fr.org>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>


---
 drivers/i2c/algos/i2c-algo-bit.c    |    2 +-
 drivers/i2c/algos/i2c-algo-ite.c    |    2 +-
 drivers/i2c/algos/i2c-algo-pca.c    |    2 +-
 drivers/i2c/algos/i2c-algo-pcf.c    |    2 +-
 drivers/i2c/algos/i2c-algo-sgi.c    |    2 +-
 drivers/i2c/algos/i2c-algo-sibyte.c |    2 +-
 drivers/i2c/busses/i2c-ibm_iic.c    |    2 +-
 7 files changed, 7 insertions(+), 7 deletions(-)

--- gregkh-2.6.orig/drivers/i2c/algos/i2c-algo-bit.c	2005-08-12 14:37:49.000000000 -0700
+++ gregkh-2.6/drivers/i2c/algos/i2c-algo-bit.c	2005-08-12 14:37:54.000000000 -0700
@@ -541,7 +541,7 @@
 
 	/* register new adapter to i2c module... */
 
-	adap->id |= i2c_bit_algo.id;
+	adap->id |= I2C_ALGO_BIT;
 	adap->algo = &i2c_bit_algo;
 
 	adap->timeout = 100;	/* default values, should	*/
--- gregkh-2.6.orig/drivers/i2c/algos/i2c-algo-ite.c	2005-08-12 14:37:49.000000000 -0700
+++ gregkh-2.6/drivers/i2c/algos/i2c-algo-ite.c	2005-08-12 14:37:54.000000000 -0700
@@ -738,7 +738,7 @@
 
 	/* register new adapter to i2c module... */
 
-	adap->id |= iic_algo.id;
+	adap->id |= I2C_ALGO_IIC;
 	adap->algo = &iic_algo;
 
 	adap->timeout = 100;	/* default values, should	*/
--- gregkh-2.6.orig/drivers/i2c/algos/i2c-algo-pca.c	2005-08-12 14:37:49.000000000 -0700
+++ gregkh-2.6/drivers/i2c/algos/i2c-algo-pca.c	2005-08-12 14:37:54.000000000 -0700
@@ -371,7 +371,7 @@
 
 	/* register new adapter to i2c module... */
 
-	adap->id |= pca_algo.id;
+	adap->id |= I2C_ALGO_PCA;
 	adap->algo = &pca_algo;
 
 	adap->timeout = 100;		/* default values, should	*/
--- gregkh-2.6.orig/drivers/i2c/algos/i2c-algo-pcf.c	2005-08-12 14:37:49.000000000 -0700
+++ gregkh-2.6/drivers/i2c/algos/i2c-algo-pcf.c	2005-08-12 14:37:54.000000000 -0700
@@ -476,7 +476,7 @@
 
 	/* register new adapter to i2c module... */
 
-	adap->id |= pcf_algo.id;
+	adap->id |= I2C_ALGO_PCF;
 	adap->algo = &pcf_algo;
 
 	adap->timeout = 100;		/* default values, should	*/
--- gregkh-2.6.orig/drivers/i2c/algos/i2c-algo-sgi.c	2005-08-12 14:37:49.000000000 -0700
+++ gregkh-2.6/drivers/i2c/algos/i2c-algo-sgi.c	2005-08-12 14:37:54.000000000 -0700
@@ -168,7 +168,7 @@
  */
 int i2c_sgi_add_bus(struct i2c_adapter *adap)
 {
-	adap->id |= sgi_algo.id;
+	adap->id |= I2C_ALGO_SGI;
 	adap->algo = &sgi_algo;
 
 	return i2c_add_adapter(adap);
--- gregkh-2.6.orig/drivers/i2c/busses/i2c-ibm_iic.c	2005-08-12 14:37:49.000000000 -0700
+++ gregkh-2.6/drivers/i2c/busses/i2c-ibm_iic.c	2005-08-12 14:37:54.000000000 -0700
@@ -726,7 +726,7 @@
 	adap = &dev->adap;
 	strcpy(adap->name, "IBM IIC");
 	i2c_set_adapdata(adap, dev);
-	adap->id = I2C_HW_OCP | iic_algo.id;
+	adap->id = I2C_ALGO_OCP | I2C_HW_OCP;
 	adap->algo = &iic_algo;
 	adap->client_register = NULL;
 	adap->client_unregister = NULL;
--- gregkh-2.6.orig/drivers/i2c/algos/i2c-algo-sibyte.c	2005-08-12 14:37:49.000000000 -0700
+++ gregkh-2.6/drivers/i2c/algos/i2c-algo-sibyte.c	2005-08-12 14:37:54.000000000 -0700
@@ -151,7 +151,7 @@
 
 	/* register new adapter to i2c module... */
 
-	i2c_adap->id |= i2c_sibyte_algo.id;
+	i2c_adap->id |= I2C_ALGO_SIBYTE;
 	i2c_adap->algo = &i2c_sibyte_algo;
         
         /* Set the frequency to 100 kHz */
